@@ -24,6 +24,12 @@ from micropython import const
 from .mcp230xx import MCP230XX
 from .digital_inout import DigitalInOut
 
+try:
+    import typing  # pylint: disable=unused-import
+    from busio import I2C
+except ImportError:
+    pass
+
 __version__ = "0.0.0-auto.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_MCP230xx.git"
 
@@ -45,7 +51,9 @@ class MCP23016(MCP230XX):
     at the specified I2C address.
     """
 
-    def __init__(self, i2c, address=_MCP23016_ADDRESS, reset=True):
+    def __init__(
+        self, i2c: I2C, address: int = _MCP23016_ADDRESS, reset: bool = True
+    ) -> None:
         super().__init__(i2c, address)
 
         if reset:
@@ -54,7 +62,7 @@ class MCP23016(MCP230XX):
             self._write_u16le(_MCP23016_IPOL0, 0x0000)
 
     @property
-    def gpio(self):
+    def gpio(self) -> int:
         """The raw GPIO output register.  Each bit represents the
         output value of the associated pin (0 = low, 1 = high), assuming that
         pin has been configured as an output previously.
@@ -62,11 +70,11 @@ class MCP23016(MCP230XX):
         return self._read_u16le(_MCP23016_GPIO0)
 
     @gpio.setter
-    def gpio(self, val):
+    def gpio(self, val: int) -> None:
         self._write_u16le(_MCP23016_GPIO0, val)
 
     @property
-    def gpioa(self):
+    def gpioa(self) -> int:
         """The raw GPIO 0 output register.  Each bit represents the
         output value of the associated pin (0 = low, 1 = high), assuming that
         pin has been configured as an output previously.
@@ -74,11 +82,11 @@ class MCP23016(MCP230XX):
         return self._read_u8(_MCP23016_GPIO0)
 
     @gpioa.setter
-    def gpioa(self, val):
+    def gpioa(self, val: int) -> None:
         self._write_u8(_MCP23016_GPIO0, val)
 
     @property
-    def gpiob(self):
+    def gpiob(self) -> int:
         """The raw GPIO 1 output register.  Each bit represents the
         output value of the associated pin (0 = low, 1 = high), assuming that
         pin has been configured as an output previously.
@@ -86,43 +94,43 @@ class MCP23016(MCP230XX):
         return self._read_u8(_MCP23016_GPIO1)
 
     @gpiob.setter
-    def gpiob(self, val):
+    def gpiob(self, val: int) -> None:
         self._write_u8(_MCP23016_GPIO1, val)
 
     @property
-    def iodir(self):
+    def iodir(self) -> int:
         """The raw IODIR direction register.  Each bit represents
         direction of a pin, either 1 for an input or 0 for an output mode.
         """
         return self._read_u16le(_MCP23016_IODIR0)
 
     @iodir.setter
-    def iodir(self, val):
+    def iodir(self, val: int) -> None:
         self._write_u16le(_MCP23016_IODIR0, val)
 
     @property
-    def iodira(self):
+    def iodira(self) -> int:
         """The raw IODIR0 direction register.  Each bit represents
         direction of a pin, either 1 for an input or 0 for an output mode.
         """
         return self._read_u8(_MCP23016_IODIR0)
 
     @iodira.setter
-    def iodira(self, val):
+    def iodira(self, val: int) -> None:
         self._write_u8(_MCP23016_IODIR0, val)
 
     @property
-    def iodirb(self):
+    def iodirb(self) -> int:
         """The raw IODIR0 direction register.  Each bit represents
         direction of a pin, either 1 for an input or 0 for an output mode.
         """
         return self._read_u8(_MCP23016_IODIR1)
 
     @iodirb.setter
-    def iodirb(self, val):
+    def iodirb(self, val: int) -> None:
         self._write_u8(_MCP23016_IODIR1, val)
 
-    def get_pin(self, pin):
+    def get_pin(self, pin: int) -> DigitalInOut:
         """Convenience function to create an instance of the DigitalInOut class
         pointing at the specified pin of this MCP23016 device.
         """
@@ -130,10 +138,10 @@ class MCP23016(MCP230XX):
             raise ValueError("Pin number must be 0-15.")
         return DigitalInOut(pin, self)
 
-    def clear_inta(self):
+    def clear_inta(self) -> None:
         """Clears port 0 interrupts."""
         self._read_u8(_MCP23016_INTCAP0)
 
-    def clear_intb(self):
+    def clear_intb(self) -> None:
         """Clears port 1 interrupts."""
         self._read_u8(_MCP23016_INTCAP1)
