@@ -18,6 +18,12 @@ from micropython import const
 from .mcp230xx import MCP230XX
 from .digital_inout import DigitalInOut
 
+try:
+    from typing import List
+    from busio import I2C
+except ImportError:
+    pass
+
 __version__ = "0.0.0-auto.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_MCP230xx.git"
 
@@ -45,7 +51,9 @@ class MCP23017(MCP230XX):
     at the specified I2C address.
     """
 
-    def __init__(self, i2c, address=_MCP23017_ADDRESS, reset=True):
+    def __init__(
+        self, i2c: I2C, address: int = _MCP23017_ADDRESS, reset: bool = True
+    ) -> None:
         super().__init__(i2c, address)
         if reset:
             # Reset to all inputs with no pull-ups and no inverted polarity.
@@ -55,7 +63,7 @@ class MCP23017(MCP230XX):
             self._write_u16le(_MCP23017_IPOLA, 0x0000)
 
     @property
-    def gpio(self):
+    def gpio(self) -> int:
         """The raw GPIO output register.  Each bit represents the
         output value of the associated pin (0 = low, 1 = high), assuming that
         pin has been configured as an output previously.
@@ -63,11 +71,11 @@ class MCP23017(MCP230XX):
         return self._read_u16le(_MCP23017_GPIOA)
 
     @gpio.setter
-    def gpio(self, val):
+    def gpio(self, val: int) -> None:
         self._write_u16le(_MCP23017_GPIOA, val)
 
     @property
-    def gpioa(self):
+    def gpioa(self) -> int:
         """The raw GPIO A output register.  Each bit represents the
         output value of the associated pin (0 = low, 1 = high), assuming that
         pin has been configured as an output previously.
@@ -75,11 +83,11 @@ class MCP23017(MCP230XX):
         return self._read_u8(_MCP23017_GPIOA)
 
     @gpioa.setter
-    def gpioa(self, val):
+    def gpioa(self, val: int) -> None:
         self._write_u8(_MCP23017_GPIOA, val)
 
     @property
-    def gpiob(self):
+    def gpiob(self) -> int:
         """The raw GPIO B output register.  Each bit represents the
         output value of the associated pin (0 = low, 1 = high), assuming that
         pin has been configured as an output previously.
@@ -87,44 +95,44 @@ class MCP23017(MCP230XX):
         return self._read_u8(_MCP23017_GPIOB)
 
     @gpiob.setter
-    def gpiob(self, val):
+    def gpiob(self, val: int) -> None:
         self._write_u8(_MCP23017_GPIOB, val)
 
     @property
-    def iodir(self):
+    def iodir(self) -> int:
         """The raw IODIR direction register.  Each bit represents
         direction of a pin, either 1 for an input or 0 for an output mode.
         """
         return self._read_u16le(_MCP23017_IODIRA)
 
     @iodir.setter
-    def iodir(self, val):
+    def iodir(self, val: int) -> None:
         self._write_u16le(_MCP23017_IODIRA, val)
 
     @property
-    def iodira(self):
+    def iodira(self) -> int:
         """The raw IODIR A direction register.  Each bit represents
         direction of a pin, either 1 for an input or 0 for an output mode.
         """
         return self._read_u8(_MCP23017_IODIRA)
 
     @iodira.setter
-    def iodira(self, val):
+    def iodira(self, val: int) -> None:
         self._write_u8(_MCP23017_IODIRA, val)
 
     @property
-    def iodirb(self):
+    def iodirb(self) -> int:
         """The raw IODIR B direction register.  Each bit represents
         direction of a pin, either 1 for an input or 0 for an output mode.
         """
         return self._read_u8(_MCP23017_IODIRB)
 
     @iodirb.setter
-    def iodirb(self, val):
+    def iodirb(self, val: int) -> None:
         self._write_u8(_MCP23017_IODIRB, val)
 
     @property
-    def gppu(self):
+    def gppu(self) -> int:
         """The raw GPPU pull-up register.  Each bit represents
         if a pull-up is enabled on the specified pin (1 = pull-up enabled,
         0 = pull-up disabled).  Note pull-down resistors are NOT supported!
@@ -132,11 +140,11 @@ class MCP23017(MCP230XX):
         return self._read_u16le(_MCP23017_GPPUA)
 
     @gppu.setter
-    def gppu(self, val):
+    def gppu(self, val: int) -> None:
         self._write_u16le(_MCP23017_GPPUA, val)
 
     @property
-    def gppua(self):
+    def gppua(self) -> int:
         """The raw GPPU A pull-up register.  Each bit represents
         if a pull-up is enabled on the specified pin (1 = pull-up enabled,
         0 = pull-up disabled).  Note pull-down resistors are NOT supported!
@@ -144,11 +152,11 @@ class MCP23017(MCP230XX):
         return self._read_u8(_MCP23017_GPPUA)
 
     @gppua.setter
-    def gppua(self, val):
+    def gppua(self, val: int) -> None:
         self._write_u8(_MCP23017_GPPUA, val)
 
     @property
-    def gppub(self):
+    def gppub(self) -> int:
         """The raw GPPU B pull-up register.  Each bit represents
         if a pull-up is enabled on the specified pin (1 = pull-up enabled,
         0 = pull-up disabled).  Note pull-down resistors are NOT supported!
@@ -156,10 +164,10 @@ class MCP23017(MCP230XX):
         return self._read_u8(_MCP23017_GPPUB)
 
     @gppub.setter
-    def gppub(self, val):
+    def gppub(self, val: int) -> None:
         self._write_u8(_MCP23017_GPPUB, val)
 
-    def get_pin(self, pin):
+    def get_pin(self, pin: int) -> DigitalInOut:
         """Convenience function to create an instance of the DigitalInOut class
         pointing at the specified pin of this MCP23017 device.
         """
@@ -168,7 +176,7 @@ class MCP23017(MCP230XX):
         return DigitalInOut(pin, self)
 
     @property
-    def ipol(self):
+    def ipol(self) -> int:
         """The raw IPOL output register.  Each bit represents the
         polarity value of the associated pin (0 = normal, 1 = inverted), assuming that
         pin has been configured as an input previously.
@@ -176,11 +184,11 @@ class MCP23017(MCP230XX):
         return self._read_u16le(_MCP23017_IPOLA)
 
     @ipol.setter
-    def ipol(self, val):
+    def ipol(self, val: int) -> None:
         self._write_u16le(_MCP23017_IPOLA, val)
 
     @property
-    def ipola(self):
+    def ipola(self) -> int:
         """The raw IPOL A output register.  Each bit represents the
         polarity value of the associated pin (0 = normal, 1 = inverted), assuming that
         pin has been configured as an input previously.
@@ -188,11 +196,11 @@ class MCP23017(MCP230XX):
         return self._read_u8(_MCP23017_IPOLA)
 
     @ipola.setter
-    def ipola(self, val):
+    def ipola(self, val: int) -> None:
         self._write_u8(_MCP23017_IPOLA, val)
 
     @property
-    def ipolb(self):
+    def ipolb(self) -> int:
         """The raw IPOL B output register.  Each bit represents the
         polarity value of the associated pin (0 = normal, 1 = inverted), assuming that
         pin has been configured as an input previously.
@@ -200,11 +208,11 @@ class MCP23017(MCP230XX):
         return self._read_u8(_MCP23017_IPOLB)
 
     @ipolb.setter
-    def ipolb(self, val):
+    def ipolb(self, val: int) -> None:
         self._write_u8(_MCP23017_IPOLB, val)
 
     @property
-    def interrupt_configuration(self):
+    def interrupt_configuration(self) -> int:
         """The raw INTCON interrupt control register. The INTCON register
         controls how the associated pin value is compared for the
         interrupt-on-change feature. If  a  bit  is  set,  the  corresponding
@@ -215,11 +223,11 @@ class MCP23017(MCP230XX):
         return self._read_u16le(_MCP23017_INTCONA)
 
     @interrupt_configuration.setter
-    def interrupt_configuration(self, val):
+    def interrupt_configuration(self, val: int) -> None:
         self._write_u16le(_MCP23017_INTCONA, val)
 
     @property
-    def interrupt_enable(self):
+    def interrupt_enable(self) -> int:
         """The raw GPINTEN interrupt control register. The GPINTEN register
         controls the interrupt-on-change feature for each pin. If a bit is
         set, the corresponding pin is enabled for interrupt-on-change.
@@ -229,11 +237,11 @@ class MCP23017(MCP230XX):
         return self._read_u16le(_MCP23017_GPINTENA)
 
     @interrupt_enable.setter
-    def interrupt_enable(self, val):
+    def interrupt_enable(self, val: int) -> None:
         self._write_u16le(_MCP23017_GPINTENA, val)
 
     @property
-    def default_value(self):
+    def default_value(self) -> int:
         """The raw DEFVAL interrupt control register. The default comparison
         value is configured in the DEFVAL register. If enabled (via GPINTEN
         and INTCON) to compare against the DEFVAL register, an opposite value
@@ -242,11 +250,11 @@ class MCP23017(MCP230XX):
         return self._read_u16le(_MCP23017_DEFVALA)
 
     @default_value.setter
-    def default_value(self, val):
+    def default_value(self, val: int) -> None:
         self._write_u16le(_MCP23017_DEFVALA, val)
 
     @property
-    def io_control(self):
+    def io_control(self) -> int:
         """The raw IOCON configuration register. Bit 1 controls interrupt
         polarity (1 = active-high, 0 = active-low). Bit 2 is whether irq pin
         is open drain (1 = open drain, 0 = push-pull). Bit 3 is unused.
@@ -258,12 +266,12 @@ class MCP23017(MCP230XX):
         return self._read_u8(_MCP23017_IOCON)
 
     @io_control.setter
-    def io_control(self, val):
+    def io_control(self, val: int) -> None:
         val &= ~0x80
         self._write_u8(_MCP23017_IOCON, val)
 
     @property
-    def int_flag(self):
+    def int_flag(self) -> List[int]:
         """Returns a list with the pin numbers that caused an interrupt
         port A ----> pins 0-7
         port B ----> pins 8-15
@@ -273,7 +281,7 @@ class MCP23017(MCP230XX):
         return flags
 
     @property
-    def int_flaga(self):
+    def int_flaga(self) -> List[int]:
         """Returns a list of pin numbers that caused an interrupt in port A
         pins: 0-7
         """
@@ -282,7 +290,7 @@ class MCP23017(MCP230XX):
         return flags
 
     @property
-    def int_flagb(self):
+    def int_flagb(self) -> List[int]:
         """Returns a list of pin numbers that caused an interrupt in port B
         pins: 8-15
         """
@@ -291,7 +299,7 @@ class MCP23017(MCP230XX):
         return flags
 
     @property
-    def int_cap(self):
+    def int_cap(self) -> List[int]:
         """Returns a list with the pin values at time of interrupt
         port A ----> pins 0-7
         port B ----> pins 8-15
@@ -300,7 +308,7 @@ class MCP23017(MCP230XX):
         return [(intcap >> pin) & 1 for pin in range(16)]
 
     @property
-    def int_capa(self):
+    def int_capa(self) -> List[int]:
         """Returns a list of pin values at time of interrupt
         pins: 0-7
         """
@@ -308,21 +316,21 @@ class MCP23017(MCP230XX):
         return [(intcapa >> pin) & 1 for pin in range(8)]
 
     @property
-    def int_capb(self):
+    def int_capb(self) -> List[int]:
         """Returns a list of pin values at time of interrupt
         pins: 8-15
         """
         intcapb = self._read_u8(_MCP23017_INTCAPB)
         return [(intcapb >> pin) & 1 for pin in range(8)]
 
-    def clear_ints(self):
+    def clear_ints(self) -> None:
         """Clears interrupts by reading INTCAP."""
         self._read_u16le(_MCP23017_INTCAPA)
 
-    def clear_inta(self):
+    def clear_inta(self) -> None:
         """Clears port A interrupts."""
         self._read_u8(_MCP23017_INTCAPA)
 
-    def clear_intb(self):
+    def clear_intb(self) -> None:
         """Clears port B interrupts."""
         self._read_u8(_MCP23017_INTCAPB)
